@@ -5,10 +5,14 @@ from informativo import forms
 from informativo import models
 
 
-class SubscribeFormView(generic.edit.CreateView):
+class SubscribeFormView(generic.edit.FormView):
     form_class = forms.SubscribeForm
     template_name = 'informativo/subscribe_form.html'
-    model = models.Contact
+
+    def form_valid(self, form):
+        response = super(SubscribeFormView, self).form_valid(form)
+        form.subscribe()
+        return response
 
     def get_context_data(self, **kwargs):
         context = super(SubscribeFormView, self).get_context_data(**kwargs)
@@ -26,7 +30,6 @@ class SubscribedView(generic.base.TemplateView):
 class UnsubscribeFormView(generic.edit.FormView):
     form_class = forms.UnsubscribeForm
     template_name = 'informativo/unsubscribe_form.html'
-    model = models.Contact
 
     def form_valid(self, form):
         response = super(UnsubscribeFormView, self).form_valid(form)
